(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    function createStore(reducer, preloadState, enhancer) {
        if (typeof preloadState === 'function'
            && typeof enhancer === 'undefined') {
            enhancer = preloadState;
            preloadState = undefined;
        }
        if (typeof enhancer !== 'undefined') {
            if (typeof enhancer !== 'function') {
                throw new Error('Expected the enhancer to be a function');
            }
            return enhancer(createStore)(reducer, preloadState);
        }
        var state;
        var listeners = [];
        var getState = function () { return state; };
        var subscribe = function (listener) {
            listeners.push(listener);
            return function () {
                var index = listeners.indexOf(listener);
                if (index > -1) {
                    listeners.splice(index, 1);
                }
            };
        };
        var dispatch = function (action) {
            state = reducer(state, action);
            listeners.forEach(function (listener) { return listener(); });
            return action;
        };
        dispatch({ type: '@@redux/INIT' });
        return {
            dispatch: dispatch,
            subscribe: subscribe,
            getState: getState
        };
    }
    exports.default = createStore;
});
//# sourceMappingURL=createStore.js.map